@@ -9,7 +9,10 @@
 #' @param input_obj phylo object or ltable
 #' @return average number of ladders
 #' @export
-avg_ladder <- function(input_obj) { # nolint
+avg_ladder <- function(input_obj) {  #nolint
+  check_tree(input_obj,
+             require_binary = TRUE,
+             require_ultrametric = FALSE)
   if (inherits(input_obj, "matrix")) {
     input_obj <- treestats::l_to_phylo(input_obj, drop_extinct = FALSE)
   }
