@@ -9,6 +9,7 @@
 #' @references  Webb, C., D. Ackerly, M. McPeek, and M. Donoghue. 2002.
 #' Phylogenies and community ecology. Annual Review of Ecology and
 #' Systematics 33:475-505.
+#'
 #' Tsirogiannis, Constantinos, Brody Sandel, and Dimitris Cheliotis.
 #' "Efficient computation of popular phylogenetic tree measures." Algorithms in
 #' Bioinformatics: 12th International Workshop, WABI 2012, Ljubljana, Slovenia,
@@ -18,11 +19,18 @@ mean_pair_dist <- function(phy, normalization = "none") {
   normalization <- check_normalization_key(normalization)
 
   if (inherits(phy, "matrix")) {
-    phy <- treestats::l_to_phylo(phy)
+    phy <- treestats::l_to_phylo(phy, drop_extinct = FALSE)
   }
+
   if (inherits(phy, "phylo")) {
-    mpd <- calc_mpd_cpp(as.vector(t(phy$edge)),
-                         phy$edge.length)
+    if (check_binary(phy)) {
+      mpd <- calc_mpd_cpp(as.vector(t(phy$edge)),
+                          phy$edge.length)
+    } else {
+      dist_mat <- ape::cophenetic.phylo(phy)
+      diag(dist_mat) <- NA
+      mpd <- mean(dist_mat, na.rm = TRUE)
+    }
     if (normalization == "tips" || normalization == TRUE) {
       n <- length(phy$tip.label)
       mpd <- mpd / (2 * log(n))
